#!/bin/sh

desktop=0
authbind=0
daemon=0
debug=0
profile=0

help()
{
    echo "Parameters:"
    echo
    echo "  --desktop : Force desktop mode in the current directory."
    echo "  --daemon  : Start in daemon mode (background). Use stop.sh to stop the node."
    echo "  --authbind: Use authbind (installed separately) to allow binding of privileged ports."
    echo "  --debug: Start in debug mode, allowing remote debugging"
    echo "  --profile: Allows remote JMX connections without ssl and authentication on port 11089"
    exit
}

while [ "$1" != "" ]; do
    case $1 in
        --desktop )    desktop=1
                       ;;
        --authbind )   authbind=1
                       ;;
        --daemon )     daemon=1
                       ;;
        --debug )      debug=1;
                       ;;
        --profile )    profile=1;
                       ;;
        * )            help
                       ;;
    esac
    shift
done

if [ $desktop -eq 1 ] && [ $daemon -eq 1 ]; then
    echo "You can't start in desktop and daemon mode at the same time. Pick one."
    exit 1
fi

DIR=`dirname "$0"`
cd "${DIR}"

# setenv.sh can be locally used to provide environment variables values
if [ -r ./setenv.sh ]; then
  . ./setenv.sh
fi

if [ -x jdk/bin/java ]; then
    JAVACMD=./jdk/bin/java
else
    JAVACMD=java
fi

if [ $debug -eq 1 ]; then
    JAVA_VER=$(${JAVACMD} -version 2>&1 | sed -n ';s/.* version "\(.*\)\.\(.*\)\..*"/\1\2/p;')
    echo Java version: $JAVA_VER
    [ "$JAVA_VER" -ge 19 ] && DEBUG_ADDRESS="*:5005" || DEBUG_ADDRESS="5005"
    JAVACMD="${JAVACMD} -agentlib:jdwp=transport=dt_socket,server=y,suspend=n,address=$DEBUG_ADDRESS "
fi

if [ $profile -eq 1 ]; then
    JAVACMD="${JAVACMD} -Dcom.sun.management.jmxremote -Dcom.sun.management.jmxremote.port=11089 -Dcom.sun.management.jmxremote.ssl=false -Dcom.sun.management.jmxremote.authenticate=false "
fi

if [ $authbind -eq 1 ]; then
    JAVACMD="authbind ${JAVACMD}"
fi

JVM_OPTS=-Xms700M
if [ -n "${ARDOR_JVM_OPTS}" ]; then
    echo "JVM options: ${ARDOR_JVM_OPTS}"
    JVM_OPTS=${ARDOR_JVM_OPTS}
fi

if [ -z "${ARDOR_PID_FILE}" ]; then
    ARDOR_PID_FILE=~/.ardor/nxt.pid
fi

if [ $desktop -eq 1 ]; then
    echo "Starting desktop mode in current directory"
    ${JAVACMD} ${JVM_OPTS} -cp classes:lib/*:conf:addons/classes:addons/lib/*:javafx-sdk/lib/* -Dnxt.runtime.mode=desktop -Dnxt.runtime.dirProvider=nxt.env.DefaultDirProvider nxt.Nxt
elif [ $daemon -eq 1 ]; then
    echo "Starting daemon mode"
    if [ -e ${ARDOR_PID_FILE} ]; then
        PID=`cat ${ARDOR_PID_FILE}`
        ps -p $PID > /dev/null
        STATUS=$?
        if [ $STATUS -eq 0 ]; then
            echo "Ardor server already running"
            exit 1
        fi
    fi
    mkdir -p "$(dirname "${ARDOR_PID_FILE}")"
    nohup ${JAVACMD} ${JVM_OPTS} -cp classes:lib/*:conf:addons/classes:addons/lib/*:javafx-sdk/lib/* nxt.Nxt > /dev/null 2>&1 &
    echo $! > ${ARDOR_PID_FILE}
else
    echo "Starting default mode"
    ${JAVACMD} ${JVM_OPTS} -cp classes:lib/*:conf:addons/classes:addons/lib/*:javafx-sdk/lib/* nxt.Nxt
fi

cd - > /dev/null
